@@ -23,13 +23,14 @@
 #include "annotate_dialog.h"
 #include "dialog_build_BOM.h"
 #include "dialog_erc.h"
-#include "dialog_find.h"
 #include "netlist_control.h"
 #include "dialog_erc.h"
 #include "libeditframe.h"
 #include "viewlib_frame.h"
 #include "hotkeys.h"
 
+#include "dialog_schematic_find.h"
+
 
 BEGIN_EVENT_TABLE( WinEDA_SchematicFrame, WinEDA_DrawFrame )
     EVT_SOCKET( ID_EDA_SOCKET_EVENT_SERV,
@@ -62,14 +63,21 @@ BEGIN_EVENT_TABLE( WinEDA_SchematicFrame, WinEDA_DrawFrame )
 
     EVT_MENU( ID_POPUP_SCH_COPY_ITEM, WinEDA_SchematicFrame::OnCopySchematicItemRequest )
 
-    EVT_MENU_RANGE( ID_CONFIG_AND_PREFERENCES_START,
-                    ID_CONFIG_AND_PREFERENCES_END,
+    EVT_MENU( ID_CONFIG_REQ,
+                WinEDA_SchematicFrame::InstallConfigFrame )
+    EVT_MENU( ID_CONFIG_SAVE,
+                WinEDA_SchematicFrame::Process_Config )
+    EVT_MENU( ID_CONFIG_READ,
+                WinEDA_SchematicFrame::Process_Config )
+    EVT_MENU_RANGE( ID_PREFERENCES_HOTKEY_START,
+                    ID_PREFERENCES_HOTKEY_END,
                     WinEDA_SchematicFrame::Process_Config )
+
     EVT_TOOL( ID_COLORS_SETUP, WinEDA_SchematicFrame::Process_Config )
     EVT_TOOL( ID_OPTIONS_SETUP, WinEDA_SchematicFrame::OnSetOptions )
 
     EVT_MENU_RANGE( ID_LANGUAGE_CHOICE, ID_LANGUAGE_CHOICE_END,
-                    WinEDA_DrawFrame::SetLanguage )
+                    WinEDA_SchematicFrame::SetLanguage )
 
     EVT_TOOL_RANGE( ID_ZOOM_IN, ID_ZOOM_PAGE, WinEDA_SchematicFrame::OnZoom )
 
@@ -137,6 +145,12 @@ BEGIN_EVENT_TABLE( WinEDA_SchematicFrame, WinEDA_DrawFrame )
     EVT_UPDATE_UI_RANGE( ID_TB_OPTIONS_SELECT_UNIT_MM,
                          ID_TB_OPTIONS_SELECT_UNIT_INCH,
                          WinEDA_SchematicFrame::OnUpdateUnits )
+
+    /* Search dialog events. */
+    EVT_FIND_CLOSE( wxID_ANY, WinEDA_SchematicFrame::OnFindDialogClose )
+    EVT_FIND_DRC_MARKER( wxID_ANY, WinEDA_SchematicFrame::OnFindDrcMarker )
+    EVT_FIND( wxID_ANY, WinEDA_SchematicFrame::OnFindSchematicItem )
+
 END_EVENT_TABLE()
 
 
@@ -164,6 +178,8 @@ WinEDA_SchematicFrame::WinEDA_SchematicFrame( wxWindow*       father,
     m_printMonochrome = true;
     m_showSheetReference = true;
     m_HotkeysZoomAndGridList = s_Schematic_Hokeys_Descr;
+    m_dlgFindReplace = NULL;
+    m_findReplaceData = new wxFindReplaceData( wxFR_DOWN );
 
     CreateScreens();
 
@@ -240,8 +256,8 @@ WinEDA_SchematicFrame::WinEDA_SchematicFrame( wxWindow*       father,
 WinEDA_SchematicFrame::~WinEDA_SchematicFrame()
 {
     SAFE_DELETE( g_RootSheet );
-    SAFE_DELETE( m_CurrentSheet ); //a SCH_SHEET_PATH, on the heap.
-    m_CurrentSheet = NULL;
+    SAFE_DELETE( m_CurrentSheet );     // a SCH_SHEET_PATH, on the heap.
+    SAFE_DELETE( m_findReplaceData );
 }
 
 
@@ -435,9 +451,16 @@ int WinEDA_SchematicFrame::BestZoom()
 wxString WinEDA_SchematicFrame::GetUniqueFilenameForCurrentSheet()
 {
     wxFileName fn = g_RootSheet->GetFileName();
-    wxString   filename = fn.GetName();
 
+#ifndef KICAD_GOST
+    wxString filename = fn.GetName();
     if( ( filename.Len() + m_CurrentSheet->PathHumanReadable().Len() ) < 50 )
+#else
+    fn.ClearExt();
+    wxString filename = fn.GetFullPath();
+    if( ( filename.Len() + m_CurrentSheet->PathHumanReadable().Len() ) < 80 )
+#endif
+
     {
         filename += m_CurrentSheet->PathHumanReadable();
         filename.Replace( wxT( "/" ), wxT( "-" ) );
@@ -604,10 +627,38 @@ void WinEDA_SchematicFrame::OnCreateBillOfMaterials( wxCommandEvent& )
 
 void WinEDA_SchematicFrame::OnFindItems( wxCommandEvent& event )
 {
+    wxASSERT_MSG( m_findReplaceData != NULL,
+                  wxT( "Forgot to create find/replace data.  Bad Programmer!" ) );
+
     this->DrawPanel->m_IgnoreMouseEvents = TRUE;
-    WinEDA_FindFrame* dlg = new WinEDA_FindFrame( this );
-    dlg->ShowModal();
-    dlg->Destroy();
+
+    if( m_dlgFindReplace )
+    {
+        delete m_dlgFindReplace;
+        m_dlgFindReplace = NULL;
+    }
+
+    m_dlgFindReplace = new DIALOG_SCH_FIND( this, m_findReplaceData, m_findDialogPosition,
+                                            m_findDialogSize );
+    m_dlgFindReplace->SetFindEntries( m_findStringHistoryList );
+    m_dlgFindReplace->SetReplaceEntries( m_replaceStringHistoryList );
+    m_dlgFindReplace->SetMinSize( m_dlgFindReplace->GetBestSize() );
+    m_dlgFindReplace->Show( true );
+}
+
+
+void WinEDA_SchematicFrame::OnFindDialogClose( wxFindDialogEvent& event )
+{
+    if( m_dlgFindReplace )
+    {
+        m_findDialogPosition = m_dlgFindReplace->GetPosition();
+        m_findDialogSize = m_dlgFindReplace->GetSize();
+        m_findStringHistoryList = m_dlgFindReplace->GetFindEntries();
+        m_replaceStringHistoryList = m_dlgFindReplace->GetReplaceEntries();
+        m_dlgFindReplace->Destroy();
+        m_dlgFindReplace = NULL;
+    }
+
     this->DrawPanel->m_IgnoreMouseEvents = FALSE;
 }
 
@@ -651,8 +702,11 @@ void WinEDA_SchematicFrame::OnOpenPcbnew( wxCommandEvent& event )
 
     if( fn.IsOk() )
     {
-        fn.ClearExt();
-        ExecuteFile( this, PCBNEW_EXE, QuoteFullPath( fn ) );
+        fn.SetExt( PcbFileExtension );
+
+        wxString filename = QuoteFullPath( fn );
+
+        ExecuteFile( this, PCBNEW_EXE, filename );
     }
     else
         ExecuteFile( this, PCBNEW_EXE );
@@ -710,3 +764,14 @@ void WinEDA_SchematicFrame::OnExit( wxCommandEvent& event )
 {
     Close( true );
 }
+
+/** function SetLanguage
+ * called on a language menu selection
+ */
+void WinEDA_SchematicFrame::SetLanguage( wxCommandEvent& event )
+{
+    WinEDA_BasicFrame::SetLanguage( event );
+    if( m_LibeditFrame )
+        m_LibeditFrame->WinEDA_BasicFrame::SetLanguage( event );
+}
+
