@@ -29,11 +29,11 @@ enum main_id
     ID_SAVE_BOARD,
     ID_SAVE_BOARD_AS,
 
-    ID_CONFIG_AND_PREFERENCES_START,
     ID_CONFIG_REQ,
     ID_CONFIG_SAVE,
     ID_CONFIG_READ,
 
+    ID_PREFERENCES_HOTKEY_START,
     ID_PREFERENCES_HOTKEY_SUBMENU,
     ID_PREFERENCES_HOTKEY_CREATE_CONFIG,
     ID_PREFERENCES_HOTKEY_READ_CONFIG,
@@ -41,10 +41,7 @@ enum main_id
     ID_PREFERENCES_HOTKEY_PATH_IS_HOME,
     ID_PREFERENCES_HOTKEY_PATH_IS_KICAD,
     ID_PREFERENCES_HOTKEY_SHOW_CURRENT_LIST,
-
-    ID_PREFERENCES_UNUSED2,
-    ID_PREFERENCES_UNUSED3,
-    ID_CONFIG_AND_PREFERENCES_END,
+    ID_PREFERENCES_HOTKEY_END,
 
     ID_GEN_PRINT,
     ID_GEN_PLOT,
