@@ -32,6 +32,10 @@ class SCH_COMPONENT;
 class SCH_FIELD;
 class LIB_PIN;
 class SCH_JUNCTION;
+class DIALOG_SCH_FIND;
+class wxFindDialogEvent;
+class wxFindReplaceData;
+
 
 /* enum used in RotationMiroir() */
 enum fl_rot_cmp
@@ -73,12 +77,18 @@ private:
     PARAM_CFG_ARRAY       m_projectFileParams;
     PARAM_CFG_ARRAY       m_configSettings;
     wxPageSetupDialogData m_pageSetupData;
+    wxFindReplaceData*    m_findReplaceData;
     wxPoint               m_previewPosition;
     wxSize                m_previewSize;
     wxPoint               m_printDialogPosition;
     wxSize                m_printDialogSize;
     bool                  m_printMonochrome;     ///< Print monochrome instead of grey scale.
     bool                  m_showSheetReference;
+    DIALOG_SCH_FIND*      m_dlgFindReplace;
+    wxPoint               m_findDialogPosition;
+    wxSize                m_findDialogSize;
+    wxArrayString         m_findStringHistoryList;
+    wxArrayString         m_replaceStringHistoryList;
 
 public:
     WinEDA_SchematicFrame( wxWindow* father,
@@ -135,7 +145,7 @@ public:
 
     virtual wxString GetScreenDesc();
 
-    void             InstallConfigFrame( const wxPoint& pos );
+    void             InstallConfigFrame( wxCommandEvent& event );
 
     void             OnLeftClick( wxDC* DC, const wxPoint& MousePos );
     void             OnLeftDClick( wxDC* DC, const wxPoint& MousePos );
@@ -214,6 +224,18 @@ public:
      */
     void             SetSheetNumberAndCount();
 
+    /** Virtual function PrintPage
+     * used to print a page
+     * Print the page pointed by ActiveScreen, set by the calling print function
+     * @param aDC = wxDC given by the calling print function
+     * @param aPrint_Sheet_Ref = true to print page references
+     * @param aPrintMask = not used here
+     * @param aPrintMirrorMode = not used here (Set when printing in mirror mode)
+     * @param aData = a pointer on an auxiliary data (not always used, NULL if not used)
+     */
+    virtual void PrintPage( wxDC* aDC, bool aPrint_Sheet_Ref,
+                    int aPrintMask, bool aPrintMirrorMode,
+                    void * aData = NULL);
     /**
      * Show the print dialog
      */
@@ -248,7 +270,7 @@ public:
     // read and save files
     void             Save_File( wxCommandEvent& event );
     void             SaveProject();
-    int              LoadOneEEProject( const wxString& FileName, bool IsNew );
+    bool             LoadOneEEProject( const wxString& FileName, bool IsNew );
     bool             LoadOneEEFile( SCH_SCREEN* screen,
                                     const wxString& FullFileName );
     bool             ReadInputStuffFile();
@@ -268,22 +290,6 @@ public:
 
     // General search:
 
-    /**
-     * Function FindSchematicItem
-     * finds a string in the schematic.
-     * @param pattern The text to search for, either in value, reference or
-     *         elsewhere.
-     * @param SearchType:  0 => Search is made in current sheet
-     *                     1 => the whole hierarchy
-     *                     2 => or for the next item
-     * @param mouseWarp If true, then move the mouse cursor to the item.
-     */
-    SCH_ITEM*        FindSchematicItem( const wxString& pattern,
-                                        int             SearchType,
-                                        bool            mouseWarp = true );
-
-    SCH_ITEM*        FindMarker( int SearchType );
-
 private:
     void             Process_Move_Item( SCH_ITEM* DrawStruct, wxDC* DC );
     void             OnExit( wxCommandEvent& event );
@@ -292,6 +298,10 @@ private:
     void             OnCreateNetlist( wxCommandEvent& event );
     void             OnCreateBillOfMaterials( wxCommandEvent& event );
     void             OnFindItems( wxCommandEvent& event );
+    void             OnFindDialogClose( wxFindDialogEvent& event );
+    void             OnFindDrcMarker( wxFindDialogEvent& event );
+    void             OnFindCompnentInLib( wxFindDialogEvent& event );
+    void             OnFindSchematicItem( wxFindDialogEvent& event );
     void             OnLoadFile( wxCommandEvent& event );
     void             OnLoadStuffFile( wxCommandEvent& event );
     void             OnNewProject( wxCommandEvent& event );
@@ -316,6 +326,11 @@ private:
     void             OnUpdateHiddenPins( wxUpdateUIEvent& event );
     void             OnUpdateBusOrientation( wxUpdateUIEvent& event );
 
+    /** function SetLanguage
+     * called on a language menu selection
+     */
+    void     SetLanguage( wxCommandEvent& event );
+
     // Bus Entry
     SCH_BUS_ENTRY*   CreateBusEntry( wxDC* DC, int entry_type );
     void             SetBusEntryShape( wxDC*          DC,
