@@ -24,7 +24,7 @@
 /* Note about the tree project build process:
  * Building the tree project can be *very* long if there are a lot of subdirectories
  * in the working directory.
- * Unfornately, this happens easily if the project file *.pro is in the home directory
+ * Unfortunately, this happens easily if the project file *.pro is in the home directory
  * So the tree project is built "on demand":
  * First the tree is built from the current directory and shows files and subdirs.
  *   > First level subdirs trees are built (i.e subdirs contents are not read)
@@ -425,7 +425,7 @@ wxString TREE_PROJECT_FRAME::GetFileExt( TreeFileType type )
         break;
 
     case TREE_PCB:
-        ext = BoardFileExtension;
+        ext = PcbFileExtension;
         break;
 
     case TREE_GERBER:
@@ -468,7 +468,7 @@ wxString TREE_PROJECT_FRAME::GetFileWildcard( TreeFileType type )
         break;
 
     case TREE_PCB:
-        ext = BoardFileWildcard;
+        ext = PcbFileWildcard;
         break;
 
     case TREE_GERBER:
@@ -704,7 +704,7 @@ void TREE_PROJECT_FRAME::ReCreateTreePrj()
     if( !fn.FileExists() )
         AddFile( fn.GetFullName(), m_root );
 
-    fn.SetExt( BoardFileExtension );
+    fn.SetExt( PcbFileExtension );
 
     if( !fn.FileExists( ) )
         AddFile( fn.GetFullName(), m_root );
