@@ -178,6 +178,15 @@ void WinEDA_PcbFrame::ReCreateMenuBar()
                            _( "Create a report of all modules on the current board" ) );
     item->SetBitmap( tools_xpm );
     submenuexport->Append( item );
+
+#if 0
+    item = new wxMenuItem( submenuexport, ID_GEN_EXPORT_FILE_VRML,
+                           _( "&VRML" ),
+                           _( "Export a VRML board representation" ) );
+    item->SetBitmap( show_3d_xpm );
+    submenuexport->Append( item );
+#endif
+
     ADD_MENUITEM_WITH_HELP_AND_SUBMENU( filesMenu, submenuexport,
                                         ID_GEN_EXPORT_FILE, _( "&Export" ),
                                         _( "Export board" ), export_xpm );
@@ -481,7 +490,7 @@ void WinEDA_PcbFrame::ReCreateMenuBar()
     wxMenu* helpMenu = new wxMenu;
     item = new wxMenuItem( helpMenu, ID_GENERAL_HELP, _( "&Contents" ),
                            _( "Open the PCBnew manual" ) );
-    item->SetBitmap( help_xpm );
+    item->SetBitmap( online_help_xpm );
     helpMenu->Append( item );
 
 
